@@ -87,6 +87,7 @@ enum reiser4_plug_type {
 	ALLOC_PLUG_TYPE         = 0xe,
 	JOURNAL_PLUG_TYPE       = 0xf,
 	KEY_PLUG_TYPE           = 0x10,
+	PARAM_PLUG_TYPE		= 0x11,
 	LAST_PLUG_TYPE
 };
 
@@ -285,20 +286,23 @@ enum reiser4_opset_id {
 	OPSET_DIRITEM		= 0x7,
 	OPSET_CRYPTO		= 0x8,
 	OPSET_DIGEST		= 0x9,
-	OPSET_COMPRES		= 0xa,
+	OPSET_CPRESS		= 0xa,
+	OPSET_CPRESS_MODE	= 0xb,
+	OPSET_CLUSTER		= 0xc,
+	OPSET_REGULAR		= 0xd,
 	
-	OPSET_STORE_LAST        = (OPSET_COMPRES + 1),
+	OPSET_STORE_LAST,
 	
 	/* These are not stored on disk in the current implementation. */
-	OPSET_CREATE		= 0xb,
-	OPSET_MKDIR		= 0xc,
-	OPSET_SYMLINK		= 0xd,
-	OPSET_MKNODE		= 0xe,
+	OPSET_CREATE		= OPSET_STORE_LAST + 1,
+	OPSET_MKDIR		= OPSET_STORE_LAST + 2,
+	OPSET_SYMLINK		= OPSET_STORE_LAST + 3,
+	OPSET_MKNODE		= OPSET_STORE_LAST + 4,
 	
 #ifndef ENABLE_MINIMAL
-	OPSET_TAIL		= 0xf,
-	OPSET_EXTENT		= 0x10,
-	OPSET_ACL		= 0x11,
+	OPSET_TAIL		= OPSET_STORE_LAST + 5,
+	OPSET_EXTENT		= OPSET_STORE_LAST + 6,
+	OPSET_ACL		= OPSET_STORE_LAST + 7,
 #endif
 	OPSET_LAST
 };
