@@ -111,7 +111,7 @@ opset_member_t opset_prof[OPSET_LAST] = {
 		.ess = 1,
 #endif
 	},
-	[OPSET_COMPRES] = {
+	[OPSET_CPRESS] = {
 		.type = INVAL_TYPE,
 #ifndef ENABLE_MINIMAL
 		.group = INVAL_PID,
@@ -119,7 +119,31 @@ opset_member_t opset_prof[OPSET_LAST] = {
 		.ess = 1,
 #endif
 	},
-	
+	[OPSET_CPRESS_MODE] = {
+		.type = INVAL_TYPE,
+#ifndef ENABLE_MINIMAL
+		.group = INVAL_PID,
+		.prof = INVAL_PID,
+		.ess = 1,
+#endif
+	},
+	[OPSET_CLUSTER] = {
+		.type = PARAM_PLUG_TYPE,
+#ifndef ENABLE_MINIMAL
+		.group = OPSET_OBJ,
+		.prof = INVAL_PID,
+		.ess = 1,
+#endif
+	},
+	[OPSET_REGULAR] = {
+		.type = INVAL_TYPE,
+#ifndef ENABLE_MINIMAL
+		.group = INVAL_PID,
+		.prof = INVAL_PID,
+		.ess = 1,
+#endif
+	},
+
 	/* Note, plugins below are not stored on-disk. */
 
 	/* The 4 plugins below needs to be splited -- for now they are used for
@@ -190,6 +214,9 @@ reiser4_plug_t *reiser4_opset_plug(rid_t member, rid_t id) {
 	if (opset_prof[member].type == INVAL_TYPE && id == 0)
 		return NULL;
 	
+	if (opset_prof[member].type == PARAM_PLUG_TYPE)
+		return NULL;
+	
 	if (!(plug = reiser4_factory_ifind(opset_prof[member].type, id)))
 		return INVAL_PTR;
 	
@@ -368,7 +395,10 @@ errno_t reiser4_opset_init(reiser4_tree_t *tree) {
 		if (!check)
 			break;
 
-		if (!tree->ent.opset[i] && opset_prof[i].type != INVAL_TYPE) {
+		if (!tree->ent.opset[i] && 
+		    opset_prof[i].type != INVAL_TYPE &&
+		    opset_prof[i].type != PARAM_PLUG_TYPE) 
+		{
 			aal_error("The slot %u in the fs-global object "
 				  "plugin set is not initialized.", i);
 			return -EINVAL;
